@@ -49,11 +49,11 @@
         /* Prototypes of functions limited to this file. */
 static Boolean position_matches(const Board *board);
 static Boolean play_moves(Game *game_details, Board *board, Move *moves,
-                unsigned max_depth);
+                unsigned max_depth, Boolean check_move_validity);
 static Boolean apply_variations(const Game *game_details,const Board *board,
-                                Variation *variation);
-static Boolean rewrite_variations(const Board *board,Variation *variation);
-static Boolean rewrite_moves(Board *board,Move *moves);
+                                Variation *variation, Boolean check_move_validity);
+static Boolean rewrite_variations(const Board *board,Variation *variation, Boolean null_move_found);
+static Boolean rewrite_moves(Board *board,Move *moves, Boolean null_move_found);
 static void append_evaluation(Move *move_details, const Board *board);
 static void append_FEN_comment(Move *move_details, const Board *board);
 static double evaluate(const Board *board);
@@ -711,13 +711,15 @@ apply_move(Colour colour,Move *move_details, Board *board)
         Piece piece_to_move = move_details->piece_to_move;
 
         if(GlobalState.output_format == EPD){
-            move_details->epd = (char *)malloc(FEN_SPACE);
+            move_details->epd = (char *) MallocOrDie(FEN_SPACE);
             build_basic_EPD_string(board,move_details->epd);
         }
 
-        make_move(move_details->from_col,move_details->from_rank,
-                        move_details->to_col,move_details->to_rank,
-                        piece_to_move,colour,board);
+	if(move_details->class != NULL_MOVE) {
+	    make_move(move_details->from_col,move_details->from_rank,
+			    move_details->to_col,move_details->to_rank,
+			    piece_to_move,colour,board);
+	}
         /* See if there are any subsiduary actions. */
         switch(move_details->class){
             case PAWN_MOVE:
@@ -752,6 +754,9 @@ apply_move(Colour colour,Move *move_details, Board *board)
                             move_details->to_rank,
                             piece_to_move,colour,board);
             break;
+	case NULL_MOVE:
+	    /* Nothing more to do. */
+	    break;
         case UNKNOWN_MOVE:
         default:
             Ok = FALSE;
@@ -786,9 +791,12 @@ apply_move(Colour colour,Move *move_details, Board *board)
         /* Play out the moves on the given board.
          * game_details is updated with the final_ and cumulative_ hash
          * values.
+	 * Check move validity unless a NULL_MOVE has been found in this
+	 * variation.
          */
 static Boolean
-play_moves(Game *game_details, Board *board, Move *moves, unsigned max_depth)
+play_moves(Game *game_details, Board *board, Move *moves, unsigned max_depth,
+           Boolean check_move_validity)
 {   Boolean game_ok = TRUE;
     /* Force a match if we aren't looking for positional variations. */
     Boolean game_matches = GlobalState.positional_variations?FALSE:TRUE;
@@ -819,78 +827,100 @@ play_moves(Game *game_details, Board *board, Move *moves, unsigned max_depth)
             /* See if there are any variations associated with this move. */
             if((next_move->Variants != NULL) && GlobalState.keep_variations){
                 game_matches |= apply_variations(game_details,board,
-						 next_move->Variants);
+						 next_move->Variants,
+						 check_move_validity);
             }
             /* Now try the main move. */
-            if(apply_move(board->to_move,next_move,board)){
-               /* Don't try for a positional match if we already have one. */
-               if(!game_matches && position_matches(board)){
-                   game_matches = TRUE;
-		   if(GlobalState.add_position_match_comments) {
-		       CommentList *comment = create_match_comment(next_move);
-		       append_comments_to_move(next_move, comment);
+	    if(next_move->class == NULL_MOVE) {
+	        /* We might not be able to check the validity of
+		 * subsequent moves.
+		 */
+#if 0
+		check_move_validity = FALSE;
+#endif
+	    }
+            if(check_move_validity) {
+		if(apply_move(board->to_move,next_move,board)){
+		   /* Don't try for a positional match if we already have one. */
+		   if(!game_matches && position_matches(board)){
+		       game_matches = TRUE;
+		       if(GlobalState.add_position_match_comments) {
+			   CommentList *comment = create_match_comment(next_move);
+			   append_comments_to_move(next_move, comment);
+		       }
 		   }
-               }
-               /* Combine this hash value with the cumulative one. */
-               game_details->cumulative_hash_value += board->hash_value;
-	       if(GlobalState.fuzzy_match_duplicates) {
-		    int plies = 2 * board->move_number - 1;
-		    /* Check who has just moved. */
-		    if(board->to_move == BLACK) {
-		        plies++;
-		    }
-	            /* Consider remembering this hash value for fuzzy matches. */
-		    if(GlobalState.fuzzy_match_depth == plies) {
-		        /* Remember it. */
-		        game_details->fuzzy_duplicate_hash = board->hash_value;
-		    }
+		   /* Combine this hash value with the cumulative one. */
+		   game_details->cumulative_hash_value += board->hash_value;
+		   if(GlobalState.fuzzy_match_duplicates) {
+			int plies = 2 * board->move_number - 1;
+			/* Check who has just moved. */
+			if(board->to_move == BLACK) {
+			    plies++;
+			}
+			/* Consider remembering this hash value for fuzzy matches. */
+			if(GlobalState.fuzzy_match_depth == plies) {
+			    /* Remember it. */
+			    game_details->fuzzy_duplicate_hash = board->hash_value;
+			}
+		   }
+		   board->to_move = OPPOSITE_COLOUR(board->to_move);
+		   if(board->to_move == WHITE){
+		       board->move_number++;
+		   }
+		   if(GlobalState.add_ECO && !GlobalState.parsing_ECO_file){
+		       int half_moves = half_moves_played(board);
+		       EcoLog *entry = eco_matches(
+			       board->hash_value,
+			       game_details->cumulative_hash_value,
+			       half_moves);
+		       if(entry != NULL){
+			   /* Consider keeping the match.
+			    * Could try to avoid spurious matches which become
+			    * more likely with larger ECO files and
+			    * the longer a game goes on.
+			    * Could be mitigated partly by preferring
+			    * an ECO line of exactly the same length as
+			    * the current game line.
+			    * Not currently implemented.
+			    */
+			   if(eco_match == NULL){
+			       /* We don't have one yet. */
+			       eco_match = entry;
+			   }
+			   else {
+			       /* Keep it anyway.
+			        * This logic always prefers a longer match
+				* to a shorter, irrespective of whether
+				* either match is exact or not.
+				* This logic was followed in versions
+				* up to and including v13.8.
+				*/
+			       eco_match = entry;
+			   }
+		       }
+		   }
+		   next_move = next_move->next;
+		}
+		else{
+		    print_error_context(GlobalState.logfile);
+		    fprintf(GlobalState.logfile,
+				    "Failed to make move %u%s %s in the game:\n",
+				    board->move_number,
+				    (board->to_move == WHITE)?".":"...",
+				    next_move->move);
+		    print_board(board,GlobalState.logfile);
+		    report_details(GlobalState.logfile);
+		    game_ok = FALSE;
+		}
+            }
+	    else {
+	        /* Go through the motions as if the move were checked. */
+	       board->to_move = OPPOSITE_COLOUR(board->to_move);
+	       if(board->to_move == WHITE){
+		   board->move_number++;
 	       }
-               board->to_move = OPPOSITE_COLOUR(board->to_move);
-               if(board->to_move == WHITE){
-                   board->move_number++;
-               }
-               if(GlobalState.add_ECO && !GlobalState.parsing_ECO_file){
-                   int half_moves = half_moves_played(board);
-                   EcoLog *entry = eco_matches(
-                           board->hash_value,
-                           game_details->cumulative_hash_value,
-                           half_moves);
-                   if(entry != NULL){
-                       /* Consider keeping the match.
-                        * Try to avoid spurious matches which become
-                        * more likely with larger ECO files and
-                        * the longer a game goes on.
-                        * Try to mitigate this partly by preferring
-                        * an ECO line of exactly the same length as
-                        * the current game line.
-                        */
-                       if(eco_match == NULL){
-                           eco_match = entry;
-                       }
-                       else {
-                           /* This logic prefers a longer match
-                            * to a shorter, irrespective of whether
-                            * either match is exact or not.
-                            * This logic was followed in versions
-                            * up to and including v13.8.
-                            */
-                           eco_match = entry;
-                       }
-                   }
-               }
-               next_move = next_move->next;
-            }
-            else{
-                print_error_context(GlobalState.logfile);
-                fprintf(GlobalState.logfile,
-                                "Failed to make move %u%s %s in the game:\n",
-                                board->move_number,
-                                (board->to_move == WHITE)?".":"...",
-                                next_move->move);
-                print_board(board,GlobalState.logfile);
-                report_details(GlobalState.logfile);
-                game_ok = FALSE;
-            }
+	       next_move = next_move->next;
+	    }
         }
         else{
             /* An empty move. */
@@ -1003,11 +1033,14 @@ play_eco_moves(Game *game_details, Board *board,Move *moves)
 }
 
         /* Play out a variation.
+	 * Check move validity unless a NULL_MOVE has been found in this
+	 * variation.
          * Return TRUE if the variation matches a position that
          * we are looking for.
          */
 static Boolean
-apply_variations(const Game *game_details,const Board *board,Variation *variation)
+apply_variations(const Game *game_details,const Board *board,Variation *variation,
+                 Boolean check_move_validity)
 {   /* Force a match if we aren't looking for positional variations. */
     Boolean variation_matches = GlobalState.positional_variations?FALSE:TRUE;
     /* Allocate space for the copies.
@@ -1029,7 +1062,8 @@ apply_variations(const Game *game_details,const Board *board,Variation *variatio
          * later matches.
          */
         variation_matches |= play_moves(copy_game,copy_board,variation->moves,
-                                        DEFAULT_POSITIONAL_DEPTH);
+                                        DEFAULT_POSITIONAL_DEPTH,
+					check_move_validity);
         variation = variation->next;
     }
     (void) free((void *)copy_game);
@@ -1060,8 +1094,10 @@ apply_move_list(Game *game_details,unsigned *plycount)
     /* Start off the cumulative hash value. */
     game_details->cumulative_hash_value = 0;
 
-    /* Play through the moves and see if we have a match. */
-    game_matches = play_moves(game_details,board,moves,max_depth);
+    /* Play through the moves and see if we have a match.
+     * Check move validity.
+     */
+    game_matches = play_moves(game_details,board,moves,max_depth,TRUE);
 
     game_details->moves_checked = TRUE;
 
@@ -1176,6 +1212,9 @@ rewrite_SAN_string(Colour colour,Move *move_details, Board *board)
             case QUEENSIDE_CASTLE:
                 /* No move list to prepare. */
                 break;
+	    case NULL_MOVE:
+                /* No move list to prepare. */
+                break;
             case UNKNOWN_MOVE:
             default:
                 fprintf(GlobalState.logfile,
@@ -1189,7 +1228,7 @@ rewrite_SAN_string(Colour colour,Move *move_details, Board *board)
                                                 move_list,board);
         }
         if((move_list == NULL) && (class != KINGSIDE_CASTLE) &&
-                        (class != QUEENSIDE_CASTLE)){
+                        (class != QUEENSIDE_CASTLE) && (class != NULL_MOVE)){
             Ok = FALSE;
         }
         /* We should now have enough information in move_details to compose a
@@ -1291,6 +1330,9 @@ rewrite_SAN_string(Colour colour,Move *move_details, Board *board)
                 case QUEENSIDE_CASTLE:
                     strcpy((char *) new_move_str,"O-O-O");
                     break;
+                case NULL_MOVE:
+                    strcpy((char *) new_move_str, (char *) NULL_MOVE_STRING);
+                    break;
                 case UNKNOWN_MOVE:
                 default:
                     Ok = FALSE;
@@ -1327,16 +1369,21 @@ rewrite_SAN_string(Colour colour,Move *move_details, Board *board)
          * Return TRUE if the move is ok, FALSE otherwise.
          */
 static Boolean
-rewrite_move(Colour colour,Move *move_details, Board *board)
+rewrite_move(Colour colour,Move *move_details, Board *board, Boolean null_move_found)
 {   /* Assume success. */
     Boolean Ok = TRUE;
 
     if(rewrite_SAN_string(colour,move_details,board)){
         Piece piece_to_move = move_details->piece_to_move;
 
-        make_move(move_details->from_col,move_details->from_rank,
-                        move_details->to_col,move_details->to_rank,
-                        piece_to_move,colour,board);
+	if(move_details->class != NULL_MOVE) {
+	    make_move(move_details->from_col,move_details->from_rank,
+			    move_details->to_col,move_details->to_rank,
+			    piece_to_move,colour,board);
+	}
+	else {
+	    null_move_found = TRUE;
+	}
         /* See if there are any subsiduary actions. */
         switch(move_details->class){
             case PAWN_MOVE:
@@ -1372,6 +1419,9 @@ rewrite_move(Colour colour,Move *move_details, Board *board)
                             move_details->to_rank,
                             piece_to_move,colour,board);
             break;
+	case NULL_MOVE:
+	    /* Nothing more. */
+	    break;
         case UNKNOWN_MOVE:
         default:
             Ok = FALSE;
@@ -1386,7 +1436,7 @@ rewrite_move(Colour colour,Move *move_details, Board *board)
 
         /* Rewrite the list of moves by playing through the game. */
 static Boolean
-rewrite_moves(Board *board,Move *moves)
+rewrite_moves(Board *board,Move *moves, Boolean null_move_found)
 {   Boolean game_ok = TRUE;
     Move *move_details = moves;
 
@@ -1395,11 +1445,15 @@ rewrite_moves(Board *board,Move *moves)
             /* See if there are any variations associated with this move. */
             if((move_details->Variants != NULL) &&
                     GlobalState.keep_variations &&
-                    !rewrite_variations(board,move_details->Variants)){
+                    !rewrite_variations(board,move_details->Variants, null_move_found)){
                 /* Something wrong with the variations. */
                 game_ok = FALSE;
             }
-            else if(rewrite_move(board->to_move,move_details,board)){
+	    /* @@@ There was a else-if here; not sure why?! */
+	    if(move_details->class == NULL_MOVE) {
+	        null_move_found = TRUE;
+	    }
+            if(rewrite_move(board->to_move,move_details,board, null_move_found)){
                 board->to_move = OPPOSITE_COLOUR(board->to_move);
 
                 if(GlobalState.output_evaluation) {
@@ -1421,7 +1475,7 @@ rewrite_moves(Board *board,Move *moves)
                     board->move_number++;
                 }
             }
-            else{
+            else {
                 fprintf(GlobalState.logfile,
                                 "Failed to rewrite move %u%s %s in the game:\n",
                                     board->move_number,
@@ -1447,7 +1501,7 @@ rewrite_moves(Board *board,Move *moves)
          * Return TRUE if the variation are ok. a position that
          */
 static Boolean
-rewrite_variations(const Board *board,Variation *variation)
+rewrite_variations(const Board *board,Variation *variation, Boolean null_move_found)
 {   Board *copy_board = allocate_new_board();
     Boolean variations_ok = TRUE;
 
@@ -1455,7 +1509,7 @@ rewrite_variations(const Board *board,Variation *variation)
         /* Work on the copy. */
         *copy_board = *board;
 
-        variations_ok = rewrite_moves(copy_board,variation->moves);
+        variations_ok = rewrite_moves(copy_board,variation->moves, null_move_found);
         variation = variation->next;
     }
     (void) free_board((void *)copy_board);
@@ -1472,7 +1526,8 @@ rewrite_game(Move *moves,const char *fen)
 {   Board *board = new_game_board(fen);
     Boolean game_ok;
 
-    game_ok = rewrite_moves(board,moves);
+    /* No null-move found at the start of the game. */
+    game_ok = rewrite_moves(board,moves,FALSE);
     if(!game_ok){
         (void) free_board((void *)board);
         board = NULL;
@@ -1638,7 +1693,11 @@ build_basic_EPD_string(const Board *board,char *epd)
     /* Build a FEN string from the given board. */
 void
 build_FEN_string(const Board *board,char *fen)
-{   size_t ix;
+{   
+    size_t ix;
+    int full_move_number =
+            board->to_move == BLACK ? board->move_number : (board->move_number + 1);
+
     build_basic_EPD_string(board,fen);
     /* Append the (pseudo) half move count and the full move count. */
     ix = strlen(fen);
@@ -1649,8 +1708,8 @@ build_FEN_string(const Board *board,char *fen)
     ix = strlen(fen);
     fen[ix] = ' '; ix++;
 
-    /* The move number. */
-    sprintf(&fen[ix],"%u",board->move_number);
+    /* The full move number. */
+    sprintf(&fen[ix],"%u", full_move_number);
 }
 
     /* Append to move_details a FEN comment of the board.
