@@ -379,12 +379,15 @@ decode_move(const unsigned char *move_string)
              Ok = FALSE;
          }
     }
+    else if(strcmp((char *) move_string, NULL_MOVE_STRING) == 0) {
+        class = NULL_MOVE;
+    }
     else{
         print_error_context(GlobalState.logfile);
         fprintf(GlobalState.logfile,"Unknown move %s.\n",move_string);
         Ok = FALSE;
     }
-    if(Ok){
+    if(Ok && class != NULL_MOVE){
         /* Allow trailing checks. */
         while(is_check(*move)){
             move++;
