@@ -39,6 +39,7 @@ typedef enum {
 /* Different classes of move determined by the lexical analyser. */
 typedef enum { PAWN_MOVE, PAWN_MOVE_WITH_PROMOTION, ENPASSANT_PAWN_MOVE,
                PIECE_MOVE, KINGSIDE_CASTLE, QUEENSIDE_CASTLE,
+	       NULL_MOVE,
                UNKNOWN_MOVE
              } MoveClass;
 /* Types for algebraic rank and column. */
@@ -119,3 +120,9 @@ typedef struct move_pair {
 #define OPPOSITE_COLOUR(colour) (!(colour))
 #define EXTRACT_COLOUR(coloured_piece) ((coloured_piece) & 0x01)
 #define EXTRACT_PIECE(coloured_piece) ((coloured_piece) >> PIECE_SHIFT)
+
+/* The string for internally representing the non-standard PGN
+ * notation for null moves.
+ */
+#define NULL_MOVE_STRING ("--")
+
