@@ -53,14 +53,6 @@ static unsigned maximum_half_moves = ECO_HALF_MOVE_LIMIT;
 #define ECO_TABLE_SIZE 4096
 static EcoLog **EcoTable;
 
-/* Rate the quality of an ECO match.
- * Currently unused.
- */
-static int eco_match_quality(EcoLog* entry,
-                      HashCode current_hash_value,
-                      HashCode cumulative_hash_value,
-                      int half_moves_played);
-
 #if INCLUDE_UNUSED_FUNCTIONS
 static void
 dumpEcoTable(void)
@@ -107,6 +99,33 @@ eco_match_level(EcoLog *entry,HashCode current_hash_value,
     return level;
 }
 
+/* Quality values for aspects of an ECO match.
+ * Currently unused.
+ */
+static int ECO_REQUIRED_HASH_VALUE = 1;
+static int ECO_HALF_MOVE_VALUE = 1;
+static int ECO_CUMULATIVE_HASH_VALUE = 0;
+
+/* Rate the quality of the given match.
+ * Currently unused.
+ */
+static int eco_match_quality(EcoLog* entry,
+                      HashCode current_hash_value,
+                      HashCode cumulative_hash_value,
+                      int half_moves_played)
+{
+    int quality = 0;
+    if(entry->required_hash_value == current_hash_value){
+        quality += ECO_REQUIRED_HASH_VALUE;
+        if(abs(half_moves_played - entry->half_moves) <= ECO_HALF_MOVE_LIMIT) {
+            quality += ECO_HALF_MOVE_VALUE;
+        }
+        if(entry->cumulative_hash_value == cumulative_hash_value){
+            quality += ECO_CUMULATIVE_HASH_VALUE;
+        }
+    }
+    return quality;
+}
 #endif
 
 void initEcoTable(void)
@@ -237,33 +256,6 @@ save_eco_details(Game game_details,unsigned number_of_half_moves)
     }
 }
 
-/* Quality values for aspects of an ECO match.
- * Currently unused.
- */
-static int ECO_REQUIRED_HASH_VALUE = 1;
-static int ECO_HALF_MOVE_VALUE = 1;
-static int ECO_CUMULATIVE_HASH_VALUE = 0;
-
-/* Rate the quality of the given match.
- * Currently unused.
- */
-static int eco_match_quality(EcoLog* entry,
-                      HashCode current_hash_value,
-                      HashCode cumulative_hash_value,
-                      int half_moves_played)
-{
-    int quality = 0;
-    if(entry->required_hash_value == current_hash_value){
-        quality += ECO_REQUIRED_HASH_VALUE;
-        if(abs(half_moves_played - entry->half_moves) <= ECO_HALF_MOVE_LIMIT) {
-            quality += ECO_HALF_MOVE_VALUE;
-        }
-        if(entry->cumulative_hash_value == cumulative_hash_value){
-            quality += ECO_CUMULATIVE_HASH_VALUE;
-        }
-    }
-    return quality;
-}
 
         /* Look in EcoTable for current_hash_value.
          * Use cumulative_hash_value to refine the match.
