@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2005 David Barnes
+ *  Copyright (C) 1994-2013 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -33,12 +33,22 @@
 #include "tokens.h"
 #include "taglist.h"
 #include "lex.h"
+#include "apply.h"
+#include "grammar.h"
+
+/**
+ * Code to handle specifications describing the state of the board
+ * in terms of numbers of pieces and material balance between opponents.
+ *
+ * Games are then matched against these specifications.
+ */
 
 /* Define a type to represent classes of occurrance. */
-typedef enum { EXACTLY, NUM_OR_MORE, NUM_OR_LESS,
-                SAME_AS_OPPONENT, NOT_SAME_AS_OPPONENT,
-                LESS_THAN_OPPONENT, MORE_THAN_OPPONENT,
-                LESS_EQ_THAN_OPPONENT, MORE_EQ_THAN_OPPONENT
+typedef enum {
+    EXACTLY, NUM_OR_MORE, NUM_OR_LESS,
+    SAME_AS_OPPONENT, NOT_SAME_AS_OPPONENT,
+    LESS_THAN_OPPONENT, MORE_THAN_OPPONENT,
+    LESS_EQ_THAN_OPPONENT, MORE_EQ_THAN_OPPONENT
 } Occurs;
 
 /* Define a structure to hold details on the occurrances of
@@ -522,6 +532,7 @@ static Boolean
 look_for_ending(Move *moves,Ending_details *details_to_find)
 {   Boolean game_ok = TRUE;
     Boolean game_matches = FALSE;
+    Boolean match_comment_added = FALSE;
     Move *next_move = moves;
     Colour colour = WHITE;
     /* The initial game position has the full set of piece details. */
@@ -572,6 +583,17 @@ look_for_ending(Move *moves,Ending_details *details_to_find)
                 game_ok = FALSE;
             }
         }
+	else {
+	    /* Match.
+	       See whether a matching comment is required.
+	     */
+	    if(GlobalState.add_position_match_comments && !match_comment_added) {
+		if(next_move != NULL) {
+		    CommentList *comment = create_match_comment(next_move);
+		    append_comments_to_move(next_move, comment);
+		}
+	    }
+	}
     }
     if(!game_ok){
         game_matches = FALSE;
