@@ -42,8 +42,9 @@
 
 static TokenType Symbol = NO_TOKEN;
 int yyparse(SourceFileType file_type);
-/* Keep track of which RAV level we are at. This is used to
- * check whether a TERMINATING_RESULT is the final one.
+/* Keep track of which RAV level we are at.
+ * This is used to check whether a TERMINATING_RESULT is the final one
+ * and whether NULL_MOVEs are allowed.
  */
 static unsigned RAV_level = 0;
 
@@ -469,6 +470,11 @@ ParseMoveUnit(void)
     if(Symbol == MOVE){
         move_details = yylval.move_details;
 
+	if(move_details->class == NULL_MOVE && RAV_level == 0) {
+            print_error_context(GlobalState.logfile);
+	    fprintf(GlobalState.logfile, "Null moves (--) only allowed in variations.\n");
+	}
+
         Symbol = next_token();
         if(Symbol == CHECK_SYMBOL){
             strcat((char *) move_details->move,"+");
@@ -951,6 +957,7 @@ DealWithEcoLine(Move *move_list)
     free_tags();
     free_move_list(current_game.moves);
 }
+
         /* If file_type == ECOFILE we are dealing with a file of ECO
          * input rather than a normal game file.
          */
