@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2005 David Barnes
+ *  Copyright (C) 1994-2013 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -25,10 +25,11 @@
          * and in finding positional variations.
          */
 typedef struct HashLog {
-    /* combined_hash_value is the XOR of the final position hash value and
+    /* Store both the final position hash value and
      * the cumulative hash value for a game.
      */
-    HashCode combined_hash_value;
+    HashCode final_hash_value;
+    HashCode cumulative_hash_value;
     /* Record the file list index for the file this game was first found in. */
     int file_number;
     struct HashLog *next;
@@ -36,4 +37,4 @@ typedef struct HashLog {
 
 void init_duplicate_hash_table(void);
 void clear_duplicate_hash_table(void);
-const char *previous_occurance(Game game_details);
+const char *previous_occurance(Game game_details, int plycount);
