@@ -234,6 +234,7 @@ init_lex_tables(void)
     ChTab['\\'] = ESCAPE;
     ChTab['\0'] = EOS;
     ChTab['*'] = STAR;
+    ChTab['-'] = DASH;
 
     /* Operators allowed only in the tag file. */
     ChTab['<'] = OPERATOR;
@@ -669,8 +670,9 @@ get_next_symbol(void)
                     token = resulting_line.token;
                     break;
                 case COMMENT_END:
-                    if(!skipping_game)
+                    if(!skipping_game) {
                         fprintf(GlobalState.logfile,"Unmatched comment end.\n");
+		    }
                     token = NO_TOKEN;
                     break;
                 case NAG:
@@ -819,6 +821,18 @@ get_next_symbol(void)
                     save_string("*");
                     token = TERMINATING_RESULT;
                     break;
+		case DASH:
+		    if(ChTab[(unsigned) *linep] == DASH) {
+		        linep++;
+			save_move((const unsigned char *) NULL_MOVE_STRING);
+			token = MOVE;
+		    }
+		    else {
+                        fprintf(GlobalState.logfile,"Single '-' not allowed.\n");
+			print_error_context(GlobalState.logfile);
+			token = NO_TOKEN;
+		    }
+		    break;
                 case EOS:
                     /* End of the string. */
                     line = next_input_line(yyin);
