@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2005 David Barnes
+ *  Copyright (C) 1994-2013 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -48,7 +48,7 @@ typedef struct{
 
 typedef struct {
     /* How many elements we have currently allocated for.
-     * If this is > 0 then we should always allocated exactly
+     * If this is > 0 then we should always have allocated exactly
      * one more than this number to simplify the (char **)NULL
      * termination of the list.
      */
@@ -78,11 +78,21 @@ static Boolean CheckList(int tag,const char *tag_string,StringArray *list);
 
 void init_tag_lists(void)
 {
+    int i;
     tag_list_length = ORIGINAL_NUMBER_OF_TAGS;
     TagLists = (StringArray *) MallocOrDie(tag_list_length*sizeof(*TagLists));
+    for(i = 0; i < tag_list_length; i++){
+	 TagLists[i].num_allocated_elements  = 0;
+	 TagLists[i].num_used_elements  = 0;
+	 TagLists[i].tag_strings  = (TagSelection *) NULL;
+    }
 }
 
-static void extend_tag_list_length(int new_length)
+    /*
+     * Extend the tag list to the new length.
+     */
+static void
+extend_tag_list_length(int new_length)
 {
     if(new_length < tag_list_length){
         fprintf(GlobalState.logfile,
@@ -350,7 +360,7 @@ extract_tag_argument(const char *argstr)
          */
 
 /* Set limits on the allowable ranges for dates extracted from games.
- * Because of the imminent century change, it is difficult to know what
+ * Because of century changes, it is difficult to know what
  * best to do with two digit year numbers; so exclude them.
  */
 #define MINDATE 100
