@@ -1355,7 +1355,13 @@ determine_move_details(Colour colour,Move *move_details, Board *board)
     else if(move_details->move[0] == '\0'){
         /* Shouldn't happen. */
         fprintf(GlobalState.logfile,
-                "Internal error: Null move in apply_move.\n");
+                "Internal error: Null move string in apply_move.\n");
+    }
+    else if(move_details->class == NULL_MOVE) {
+        /* Non-standard PGN.
+	 * Nothing more to be done.
+	 */
+	Ok = TRUE;
     }
     else{
         /* We have something -- normal case. */
