@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2005 David Barnes
+ *  Copyright (C) 1994-2013 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -25,7 +25,7 @@ Boolean determine_move_details(Colour colour,Move *move_details, Board *board);
 HashCode HashLookup(Col col, Rank rank, Piece piece, Colour colour);
 void make_move(Col from_col, Rank from_rank, Col to_col, Rank to_rank,
                 Piece piece, Colour colour,Board *board);
-Boolean king_is_in_check(const Board *board,Colour king_colour);
+CheckStatus king_is_in_check(const Board *board,Colour king_colour);
 MovePair *find_pawn_moves(Col from_col, Rank from_rank, Col to_col,Rank to_rank,
                 Colour colour, const Board *board);
 MovePair *find_knight_moves(Col to_col,Rank to_rank, Colour colour, const Board *board);
