@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2007 David Barnes
+ *  Copyright (C) 1994-2013 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -46,6 +46,7 @@
 #include "moves.h"
 #include "apply.h"
 #include "decode.h"
+#include "fenmatcher.h"
 
 /* Define a character that can be used in the variations file to
  * mean that we don't mind what move was played at this point.
@@ -362,6 +363,15 @@ add_fen_positional_match(const char *fen_string)
     GlobalState.positional_variations = TRUE;
 }
 
+        /* Treat fen_pattern as being a position to be matched.
+         */
+void
+add_fen_pattern_match(const char *fen_pattern)
+{
+    add_fen_pattern(fen_pattern);
+    GlobalState.positional_variations = TRUE;
+}
+
         /* Roughly define a move character for the purposes of textual
          * matching.
          */
@@ -757,9 +767,10 @@ check_textual_variations(Game game_details)
          * is within the bounds of what we want.
          */
 Boolean
-check_move_bounds(unsigned number_of_moves)
+check_move_bounds(unsigned plycount)
 {   Boolean in_bounds = TRUE;
 
+    unsigned number_of_moves = (plycount + 1) / 2;
     if(GlobalState.check_move_bounds){
          in_bounds = (GlobalState.lower_move_bound <= number_of_moves) &&
                          (number_of_moves <= GlobalState.upper_move_bound);
