@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2007 David Barnes
+ *  Copyright (C) 1994-2013 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -25,7 +25,8 @@ void add_positional_variation_from_line(char *line);
 void add_textual_variations_from_file(FILE *fpin);
 void add_textual_variation_from_line(char *line);
 Boolean check_textual_variations(Game game_details);
-Boolean check_move_bounds(unsigned number_of_moves);
+Boolean check_move_bounds(unsigned plycount);
 void add_fen_positional_match(const char *fen_string);
+void add_fen_pattern_match(const char *fen_pattern);
 Boolean check_for_only_checkmate(const Move *moves);
 Boolean check_for_only_stalemate(const Board *board, const Move *moves);
