@@ -605,6 +605,9 @@ print_move(FILE *outputfile, unsigned move_number, unsigned print_move_number,
                                        move_details->to_rank,
                                        promoted_piece_letter(move_details->promoted_piece));
                                    break;
+			       case NULL_MOVE:
+			           strcpy(algebraic, NULL_MOVE_STRING);
+				   break;
                                case UNKNOWN_MOVE:
                                    strcpy(algebraic,"???");
                                    break;
@@ -637,17 +640,24 @@ print_move(FILE *outputfile, unsigned move_number, unsigned print_move_number,
                                ind = strlen(algebraic);
                            }
                            /* Format the basics. */
-                           sprintf(&algebraic[ind],"%c%c%c%c",
-                                       move_details->from_col,
-                                       move_details->from_rank,
-                                       move_details->to_col,
-                                       move_details->to_rank);
-                           ind += 4;
+			   if(move_details->class != NULL_MOVE) {
+			       sprintf(&algebraic[ind],"%c%c%c%c",
+					   move_details->from_col,
+					   move_details->from_rank,
+					   move_details->to_col,
+					   move_details->to_rank);
+			       ind += 4;
+			   }
+			   else {
+			       strcpy(algebraic, NULL_MOVE_STRING);
+			       ind += strlen(NULL_MOVE_STRING);
+			   }
                            switch(move_details->class){
                                case PAWN_MOVE:
                                case KINGSIDE_CASTLE:
                                case QUEENSIDE_CASTLE:
                                case PIECE_MOVE:
+			       case NULL_MOVE:
                                    /* Nothing more to do at this stage. */
                                    break;
                                case ENPASSANT_PAWN_MOVE:
