@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2005 David Barnes
+ *  Copyright (C) 1994-2013 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -31,8 +31,9 @@
      *     HALG: Hyphenated long-algebraic, e.g. e2-e4.
      *     ELALG: Enhanced long-algebraic. Includes piece names, e.g. Ng1f3,
      *            and en-passant notation.
+     *     UCI: UCI-compatible format - actually LALG.
      */
-typedef enum { SOURCE, SAN, EPD, CM, LALG, HALG, ELALG } OutputFormat;
+typedef enum { SOURCE, SAN, EPD, CM, LALG, HALG, ELALG, UCI } OutputFormat;
 
     /* Define a type to specify whether a move gives check, checkmate,
      * or nocheck.
@@ -45,12 +46,12 @@ typedef enum { NOCHECK, CHECK, CHECKMATE } CheckStatus;
          * list of NAGs, etc.
          */
 typedef struct string_list {
-    char *str;
+    const char *str;
     struct string_list *next;
 } StringList;
 
 /* The following function is used for linking list items together. */
-StringList *SaveStringListItem(StringList *list,char *str);
+StringList *SaveStringListItem(StringList *list,const char *str);
 
 typedef struct comment_list{
     StringList *Comment;
@@ -124,6 +125,8 @@ typedef struct {
      * of final_hash_value.
      */
     HashCode cumulative_hash_value;
+    /* Board hash value at fuzzy_move_depth, if required. */
+    HashCode fuzzy_duplicate_hash;
     /* The move list of the game. */
     Move *moves;
     /* Whether the moves have been checked, or not. */
@@ -164,25 +167,15 @@ typedef enum {
  * Most of these fields are set from the program's arguments.
  */
 typedef struct {
-    /* Whether to check, but not write the converted output.
-     * This is set with the -r flag.
-     */
+    /* Whether to check, but not write the converted output. */
     Boolean check_only;
-    /* Whether to print a running commentary to logfile.
-     * Set to FALSE with the -s flag.
-     */
+    /* Whether to print a running commentary to logfile. */
     Boolean verbose;
-    /* Whether to keep NAGs along with moves.
-     * This is cleared with the -N flag.
-     */
+    /* Whether to keep NAGs along with moves. */
     Boolean keep_NAGs;
-    /* Whether to keep comments along with moves.
-     * This is cleared with the -C flag.
-     */
+    /* Whether to keep comments along with moves. */
     Boolean keep_comments;
-    /* Whether to keep variations along with moves.
-     * This is cleared with the -V flag.
-     */
+    /* Whether to keep variations along with moves. */
     Boolean keep_variations;
     /* Which tags are to be output. */
     TagOutputForm tag_output_format;
@@ -196,6 +189,10 @@ typedef struct {
     Boolean suppress_duplicates;
     /* Whether to suppress unique game scores. */
     Boolean suppress_originals;
+    /* Whether to use fuzzy matching for duplicates. */
+    Boolean fuzzy_match_duplicates;
+    /* At what depth to use fuzzy matching. */
+    int fuzzy_match_depth;
     /* Whether to check the tags for matches. */
     Boolean check_tags;
     /* Whether to add ECO codes. */
@@ -206,9 +203,9 @@ typedef struct {
     EcoDivision ECO_level;
     /* What form to write the output in. */
     OutputFormat output_format;
-    /* Maximum output line length.  Set with -w flag. */
+    /* Maximum output line length. */
     unsigned max_line_length;
-    /* Whether to use a virtual hash table or not. Set with -Z flag. */
+    /* Whether to use a virtual hash table or not. */
     Boolean use_virtual_hash_table;
     /* Whether to match on the number of moves in a game. */
     Boolean check_move_bounds;
@@ -220,6 +217,8 @@ typedef struct {
     Boolean keep_move_numbers;
     /* Whether to output results in the output. */
     Boolean keep_results;
+    /* Whether to keep check and mate characters in the output. */
+    Boolean keep_checks;
     /* Whether to output an evaluation value after each move. */
     Boolean output_evaluation;
     /* Maximum depth to which to search for positional variations.
@@ -239,6 +238,12 @@ typedef struct {
     unsigned output_ply_limit;
     /* Whether to output a FEN string at the end of the game. */
     Boolean output_FEN_string;
+    /* Whether to add a FEN comment after every move. */
+    Boolean add_FEN_comments;
+    /* Whether to add a 'matching position' comment. */
+    Boolean add_position_match_comments;
+    /* The comment to use for position matches, if required. */
+    const char *position_match_comment;
     /* Current input file name. */
     const char *current_input_file;
     /* Whether this is a CHECKFILE or a NORMALFILE. */
@@ -249,15 +254,11 @@ typedef struct {
     FILE *outputfile;
     /* Output file name. */
     const char *output_filename;
-    /* Where to write errors and running commentary.
-     * Set with the -l flag.
-     */
+    /* Where to write errors and running commentary. */
     FILE *logfile;
     /* Where to write duplicate games. */
     FILE *duplicate_file;
-    /* Where to write games that don't match the criteria.
-     * Set with the -n flag.
-     */
+    /* Where to write games that don't match the criteria. */
     FILE *non_matching_file;
 } StateInfo;
 
